@@ -264,6 +264,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import cdk8s
@@ -288,6 +290,11 @@ class CustomResourceProvider:
         :param handler: The construct handler.
         :param kind: Kind of this custom resource.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CustomResourceProvider.__init__)
+            check_type(argname="argument api_version", value=api_version, expected_type=type_hints["api_version"])
+            check_type(argname="argument handler", value=handler, expected_type=type_hints["handler"])
+            check_type(argname="argument kind", value=kind, expected_type=type_hints["kind"])
         self._values: typing.Dict[str, typing.Any] = {
             "api_version": api_version,
             "handler": handler,
@@ -366,6 +373,11 @@ class _ICustomResourceProviderHandlerProxy:
         :param id: -
         :param spec: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ICustomResourceProviderHandler.apply)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument spec", value=spec, expected_type=type_hints["spec"])
         return typing.cast(constructs.Construct, jsii.invoke(self, "apply", [scope, id, spec]))
 
 # Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
@@ -439,6 +451,10 @@ class OperatorProps:
         :param input_file: A Kubernetes JSON manifest with a single resource that is matched against one of the providers within this operator. Default: - first position command-line argument or "/dev/stdin"
         :param output_file: Where to write the synthesized output. Default: "/dev/stdout"
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(OperatorProps.__init__)
+            check_type(argname="argument input_file", value=input_file, expected_type=type_hints["input_file"])
+            check_type(argname="argument output_file", value=output_file, expected_type=type_hints["output_file"])
         self._values: typing.Dict[str, typing.Any] = {}
         if input_file is not None:
             self._values["input_file"] = input_file
@@ -495,6 +511,9 @@ class Server(metaclass=jsii.JSIIMeta, jsii_type="cdk8s-operator.Server"):
 
         :param port: The port to listen to. If not specified, the ``PORT`` environment variable will be used. If that's not specified an available port will be auto-selected.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Server.listen)
+            check_type(argname="argument port", value=port, expected_type=type_hints["port"])
         return typing.cast(jsii.Number, jsii.ainvoke(self, "listen", [port]))
 
 
@@ -508,6 +527,9 @@ class ServerProps:
         '''
         :param app_command: The command to execute in order to synthesize the CDK app.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ServerProps.__init__)
+            check_type(argname="argument app_command", value=app_command, expected_type=type_hints["app_command"])
         self._values: typing.Dict[str, typing.Any] = {
             "app_command": app_command,
         }
